package Cobol::Compiler::Lexer;

sub new {
	my ($class) = @_;

	my $self = { };

	$class = ref($class) || $class;

	bless $self, $class;
}

sub switch {
	my ($self) = @_;

}

1;
